importpdf

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2026 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Overview

Package importpdf provides helpers for importing pages from existing PDFs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Page

func Page(pdf *document.Document, sourceFile string, pageNo int, box string) int

Page imports a page from sourceFile into pdf and returns its page ID.

func PageStream

func PageStream(pdf *document.Document, source io.Reader, pageNo int, box string) int

PageStream imports a page from source into pdf and returns its page ID.

func UsePage

func UsePage(pdf *document.Document, pageID int, x, y, w, h float64)

UsePage draws an imported page on pdf.

Types

This section is empty.

Jump to