testpdf

package
v0.5.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2026 License: MPL-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package testpdf provides internal deterministic PDF test helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompareBytes

func CompareBytes(sl1, sl2 []byte, printDiff bool) (err error)

CompareBytes compares the bytes referred to by sl1 with those referred to by sl2. nil is returned if the buffers are equal; otherwise an error is returned.

func ComparePDFFiles

func ComparePDFFiles(file1Str, file2Str string, printDiff bool) (err error)

ComparePDFFiles reads and compares the full contents of the two specified files byte-for-byte. nil is returned if the file contents are equal or if the second file cannot be read; otherwise an error is returned.

func ComparePDFs

func ComparePDFs(rdr1, rdr2 io.Reader, printDiff bool) (err error)

ComparePDFs reads and compares the full contents of the two specified readers byte-for-byte. nil is returned if the buffers are equal; otherwise an error is returned.

Types

This section is empty.

Jump to