package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Jun 9, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package importpdf provides helpers for importing pages from existing PDFs.
-
func Page(pdf *document.Document, sourceFile string, pageNo int, box string) int
-
func PageStream(pdf *document.Document, source io.Reader, pageNo int, box string) int
-
func UsePage(pdf *document.Document, pageID int, x, y, w, h float64)
Page imports a page from sourceFile into pdf and returns its page ID.
PageStream imports a page from source into pdf and returns its page ID.
UsePage draws an imported page on pdf.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.