Documentation
¶
Overview ¶
Package testpdf provides internal deterministic PDF test helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CompareBytes ¶
CompareBytes compares the bytes referred to by sl1 with those referred to by sl2. nil is returned if the buffers are equal; otherwise an error is returned.
func ComparePDFFiles ¶
ComparePDFFiles reads and compares the full contents of the two specified files byte-for-byte. nil is returned if the file contents are equal or if the second file cannot be read; otherwise an error is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.